[Cmake-commits] CMake branch, next, updated. v2.8.7-2694-g39f0585

Rolf Eike Beer eike at sf-mail.de
Sat Feb 18 05:58:42 EST 2012


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  39f0585e97783fa86779ad0c2067700f013f4a24 (commit)
       via  27501155c7bcc04ada498407ad3d6fd40dbea2bd (commit)
       via  bfbb57508603ab6c7007d75718b21868b690e151 (commit)
      from  f6b791bedefedf3fefb86bb7f893749a88715d5f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=39f0585e97783fa86779ad0c2067700f013f4a24
commit 39f0585e97783fa86779ad0c2067700f013f4a24
Merge: f6b791b 2750115
Author:     Rolf Eike Beer <eike at sf-mail.de>
AuthorDate: Sat Feb 18 05:58:38 2012 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Sat Feb 18 05:58:38 2012 -0500

    Merge topic 'improve-findpkgconfig' into next
    
    2750115 FindPkgConfig: support version selection of pkg-config itself
    bfbb575 KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=27501155c7bcc04ada498407ad3d6fd40dbea2bd
commit 27501155c7bcc04ada498407ad3d6fd40dbea2bd
Author:     Rolf Eike Beer <eike at sf-mail.de>
AuthorDate: Sat Feb 18 11:57:38 2012 +0100
Commit:     Rolf Eike Beer <eike at sf-mail.de>
CommitDate: Sat Feb 18 11:57:38 2012 +0100

    FindPkgConfig: support version selection of pkg-config itself

diff --git a/Modules/FindPkgConfig.cmake b/Modules/FindPkgConfig.cmake
index ce58899..5d93ab1 100644
--- a/Modules/FindPkgConfig.cmake
+++ b/Modules/FindPkgConfig.cmake
@@ -13,14 +13,17 @@
 # When the 'QUIET' argument is set, no status messages will be printed.
 #
 # It sets the following variables:
 #   PKG_CONFIG_FOUND         ... true if pkg-config works on the system
 #   PKG_CONFIG_EXECUTABLE    ... pathname of the pkg-config program
 #   <PREFIX>_FOUND           ... set to 1 if module(s) exist
 #
 # For the following variables two sets of values exist; first one is the
 # common one and has the given PREFIX. The second set contains flags
 # which are given out when pkgconfig was called with the '--static'
 # option.
+#   <XPREFIX>_FOUND          ... set to 1 if module(s) exist
 #   <XPREFIX>_LIBRARIES      ... only the libraries (w/o the '-l')
 #   <XPREFIX>_LIBRARY_DIRS   ... the paths of the libraries (w/o the '-L')
 #   <XPREFIX>_LDFLAGS        ... all required linker flags
@@ -89,9 +92,17 @@ set(PKG_CONFIG_VERSION 1)
 find_program(PKG_CONFIG_EXECUTABLE NAMES pkg-config DOC "pkg-config executable")
 mark_as_advanced(PKG_CONFIG_EXECUTABLE)
 
-include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-find_package_handle_standard_args(PkgConfig DEFAULT_MSG PKG_CONFIG_EXECUTABLE)
+if (PKG_CONFIG_EXECUTABLE)
+  execute_process(COMMAND ${PKG_CONFIG_EXECUTABLE} --version
+    OUTPUT_VARIABLE PKG_CONFIG_VERSION_STRING
+    ERROR_QUIET
+    OUTPUT_STRIP_TRAILING_WHITESPACE)
+endif (PKG_CONFIG_EXECUTABLE)
 
+include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
+find_package_handle_standard_args(PkgConfig
+                                  REQUIRED_VARS PKG_CONFIG_EXECUTABLE
+                                  VERSION_VAR PKG_CONFIG_VERSION_STRING)
 
 # Unsets the given variables
 macro(_pkgconfig_unset var)

-----------------------------------------------------------------------

Summary of changes:
 Modules/FindPkgConfig.cmake       |   21 ++++++++++++++++-----
@@ -13,14 +13,17 @@
 #
 # It sets the following variables:
-#   PKG_CONFIG_FOUND         ... true if pkg-config works on the system
-#   PKG_CONFIG_EXECUTABLE    ... pathname of the pkg-config program
-#   <PREFIX>_FOUND           ... set to 1 if module(s) exist
+#   PKG_CONFIG_FOUND          ... true if pkg-config works on the system
+#   PKG_CONFIG_EXECUTABLE     ... pathname of the pkg-config program
+#   PKG_CONFIG_VERSION_STRING ... the version of the pkg-config program found
+#                                 (since CMake 2.8.8)
+#   PKG_CONFIG_FOUND          ... if pkg-config executable was found
 #
 # For the following variables two sets of values exist; first one is the
 Source/kwsys/kwsysDateStamp.cmake |    2 +-
 2 files changed, 17 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list